let fs = require("fs");
let path = require("path");
let mkdirp = require("mkdirp");

const staticDir = path.join(__dirname, "static");

module.exports = (app) => {
    function renderAndSave(file, template, options) {
        file = path.join(staticDir, file);
        mkdirp.sync(path.join(file, ".."));
        options.layout = "html";
        app.render(template, options, (e, r) => {
            if (e) return fs.writeFile(file, "<!DOCTYPE html><html><head><title>Something went wrong!</title></head><body><h1>Something went wrong!</h1><p>Could not render this page! Please contact the administrator!</p></body></html>", () => undefined);
            return fs.writeFile(file, r, () => undefined);
        });
    }

    if (!fs.existsSync(staticDir)) fs.mkdirSync(staticDir);

    [
        ["impressum.htm", "impressum", { title: "Impressum" } ],
        ["index.htm", "main", {
            title: "#Blackout21 on BananaNetwork",
            ownPages: [
                { href: "https://banananet.work", name: "Hauptseite des BananaNetwork" },
                { href: "https://git.banananet.work", name: "BananaNetwork Git Repository" },
                { href: "https://dsa.banananet.work", name: "DSA Events" },
                { href: "https://forumderschan.de", name: "Forum der Schan.de" },
            ],
            supportPages: [
                { href: "https://pledge2019.eu/", name: "... die Abgeordneten des Europäischen Parlaments zu kontaktieren und sie über Ihre Haltung zur geplanten Reform zu informieren." },
                { href: "https://www.google.com/maps/d/u/0/viewer?mid=1tHaOiCgjION6hK0rrajIJyuHnG5FgBzH&ll=51.57737179436094%2C12.027556413738921&z=6", name: "... an den Demonstrationen teilzunehmen, die am 23. März 2019 in ganz Europa stattfinden." },
                { href: "https://www.diesmalwaehleich.eu", name: "... Ihr demokratisches Recht wahrzunehmen und am 26. Mai 2019 an der Wahl des EU-Parlaments teilzunehmen." },
                { href: "https://www.literaturcafe.de/artikel-12-der-urheberrechtsreform-warum-buchautoren-kuenftig-weniger-verdienen-werden/", name: "... dass Urheber sich darüber informieren, wie ihnen die aktuelle Version der Reform in Form von Artikel 12 schadet." },
            ],
            externalPages: [
                { href: "https://de.wikipedia.org", name: "Wikipedia Deutschland" },
                { href: "https://blackout21.eu/en/index.html", name: "#Blackout21" },
                { href: "https://foren-gegen-uploadfilter.eu/", name: "Foren gegen Upload-Filter" },
                { href: "https://www.zum.de/portal/", name: "Zentrale für Unterrichtsmedien im Internet e.V." },
                { href: "https://pga13.eu/", name: "Phantast*innen gegen Artikel 13" },
                { href: "https://jodel.com/", name: "Jodel (kein Blackout, aktivieren jedoch \"Upload Filter\")" },
                { href: "https://network.cdresel.de/", name: "Christians Network Blog" },
                { href: "https://blog.jonashagendorf.de/", name: "Blog.JonasHagendorf.de" },
                { href: "https://www.nimoo.de", name: "nimoo" },
            ],
            infoPages: [
                { href: "https://savetheinternet.info", name: "Save the Internet" },
                { href: "https://saveyourinternet.eu/de", name: "#SaveYourInternet" },
                { href: "https://www.ohchr.org/en/NewsEvents/Pages/DisplayNews.aspx?NewsID=24298&LangID=E", name: "UN-Beauftragter David Kaye nimmt Stellung zur Reform" },
                { href: "https://www.wbs-law.de/urheberrecht/artikel-13-analyse-der-hintergruende-pro-und-contra-argumente-sowie-alternativen-79862/", name: "Artikel 13 - Analyse der Hintergründe, Pro- und Contra-Argumente sowie Alternativen von Rechtsanwalt Christian Solmecke"},
                { href: "https://www.change.org/p/stoppt-die-zensurmaschine-rettet-das-internet-uploadfilter-artikel13-saveyourinternet", name: "Petition: Stoppt die Zensurmaschine - Rettet das Internet! #Uploadfilter #Artikel13" },
                { href: "https://pledge2019.eu/de", name: "Pledge 2019: Gegen Artikel 13" },
                { href: "https://botbrief.eu/", name: "BotBrief.eu | Dein Brief an die Europaabgeordneten" },
            ],
        }],
    ].forEach(e => renderAndSave(e[0], e[1], e[2]));
};
